Using stylesheets and javascript in your course — OppiaMobile 0.4.2 documentation

### Navigation

- index
- next |
- previous |
- OppiaMobile 0.4.2 documentation »
- Customisation »

# Using stylesheets and javascript in your course

The Moodle oppia export block comes by default with a single style that will be applied to any courses you export - so the stylesheet and related resources (images etc) will get exported to the course package too.

## Creating your own style

To add a new style (or adapt the existing one), create an new css file in the <block>/styles directory, along with a new directory for the resources (see the current folder structure).

### Navigation

- index
- next |
- previous |
- OppiaMobile 0.4.2 documentation »
- Customisation »